#
# @author Sebastián Rodríguez Robotham
# receive some params
# @param name param name
# @param value param value
#
class HuemulParam:
    def __init__(self, name, value):
        self.name = name
        self.value = value